@@ -22,6 +22,7 @@
 
 #include "driver.h"
 #include "vkontakte.h"
+#include "parser.h"
 #define XSL_URL DATADIR"/msa/drivers/vkontakte/make_url.xsl"
 
 #ifdef TEST
@@ -40,7 +41,7 @@ int init_event_manager(int time)
 #endif
 g_debug("init_event_maneger start");
 /** request **/
-char* event_message = "\
+xmlChar* event_message = xmlCharStrdup("\
 <TransitData id=\"0\" type=\"data\">\
 <SourceID>db</SourceID>\
 <TargetID>vkontakte</TargetID>\
@@ -49,16 +50,16 @@ char* event_message = "\
 <Params/>\
 </Request>\
 </Content>\
-</TransitData>";
+</TransitData>");
 
     char* action;
     if (time == 0) {
         action = g_strdup("remove");
     } else
         action = g_strdup("set");
-    char* str_time = g_strdup_printf("%d",time);
+    gchar* str_time = g_strdup_printf("%d", time);
 
-    char* event_struct = g_strconcat("\
+    gchar* event_struct_str = g_strconcat("\
 <TransitData type=\"signal\">\
 <SourceID>"KERNEL_ID"</SourceID>\
 <TargetID>", HANDLER_ID, "</TargetID>\
@@ -71,9 +72,10 @@ char* event_message = "\
 </Signal>\
 </Content>\
 </TransitData>", NULL);
+    xmlChar * event_struct = xmlCharStrdup(event_struct_str);
+    g_free(event_struct_str);
     free(action);
     free(str_time);
-    GList* list;
 
     xmlNodePtr node;
     xmlNodePtr node_root;
@@ -104,7 +106,8 @@ char* event_message = "\
     xmlXPathFreeObject(Obj);
     xmlFreeDoc(doc);
     xmlFreeDoc(doc_root);
-    g_free(event_struct);
+    xmlFree(event_struct);
+    xmlFree(event_message);
     return 0;
 }
 
@@ -182,15 +185,12 @@ static char* get_captcha(guint32 captcha_sid)
  */
 int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info)
 {
-    int i, len;
     int captch = 0;
     int init_status = 0;
-    char* url = NULL;
     gchar* remixmid = NULL;
     gchar* remixsid = NULL;
-    gchar* class = NULL;
-    gchar* function = NULL;
-    gchar* tmp = NULL;
+    xmlChar* class_val = NULL;
+    xmlChar* function = NULL;
     xmlXPathObject *Obj = NULL;
 
     global_temp++;
@@ -202,41 +202,40 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info)
 //Prepare response
     xmlNodePtr rootNode = NULL, node = NULL, childNode = NULL;
     xmlDocPtr reqXml2 = NULL;
-    rootNode = xmlNewDocNode(doc, NULL,  "Response", NULL);
+    rootNode = xmlNewDocNode(doc, NULL, BAD_CAST "Response", NULL);
     xmlDocSetRootElement(doc, rootNode);
 
-    class = get_req_class(reqXml);
+    class_val = get_req_class(reqXml);
     function = get_req_function(reqXml);
-    xmlSetProp(rootNode, CLASS, class);
-    g_free(class);
-    class = NULL;
-    xmlSetProp(rootNode, FUNCTION, function);
+    xmlSetProp(rootNode, BAD_CAST CLASS, class_val);
+    xmlFree(class_val);
+    class_val = NULL;
+    xmlSetProp(rootNode, BAD_CAST FUNCTION, function);
     
-    node = xmlNewDocNode(doc, NULL,   PARAMS,  NULL);
+    node = xmlNewDocNode(doc, NULL, BAD_CAST PARAMS,  NULL);
     childNode = xmlAddChild(rootNode, node);
  
-    xmlNodePtr node2 = NULL;
     g_debug("function = %s", function);
-    if (g_strcmp0(function, GET_SETTINGS) == 0) {
+    if (g_strcmp0((gchar *)function, GET_SETTINGS) == 0) {
         get_settings(doc);
-        g_free(function);
+        xmlFree(function);
        return 0;
     }
     
-    if(g_strcmp0(function, SET_SETTINGS) == 0) {
+    if(g_strcmp0((gchar *)function, SET_SETTINGS) == 0) {
         if (set_settings(reqXml, doc, info)) {
             info_message("404", doc, DRV_SETT_ERROR, 1);
         } else {
             info_message("410", doc, DRV_SETT_SAVED, 0);
         }
-       g_free(function);
+       xmlFree(function);
        return 0;
     }
-    if (g_strcmp0(function, CAPTCHA_MESSAGE) == 0) {
-        g_free(function);
+    if (g_strcmp0((gchar *)function, CAPTCHA_MESSAGE) == 0) {
+        xmlFree(function);
         captch = 1;
 
-        char* captcha_code = NULL;
+        xmlChar* captcha_code = NULL;
         Obj = xpath("//Request/Params/string[@name='text']", reqXml);
         node = Obj->nodesetval->nodeTab[0];
         captcha_code = xmlNodeGetContent(node);
@@ -254,7 +253,7 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info)
             node = Obj->nodesetval->nodeTab[0];
             childNode = xmlCopyNode(node,1);
             xmlUnlinkNode(childNode);
-            reqXml2 = xmlNewDoc("1.0");
+            reqXml2 = xmlNewDoc(BAD_CAST "1.0");
             xmlDocSetRootElement(reqXml2, childNode);
             xmlXPathFreeObject(Obj);
         } else {
@@ -263,15 +262,15 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info)
     }
 
     if(captch) {
-        class = get_req_class(reqXml2);
+        class_val = get_req_class(reqXml2);
         function = get_req_function(reqXml2);
-        xmlSetProp(rootNode, CLASS, class);
-        xmlSetProp(rootNode, FUNCTION, function);
+        xmlSetProp(rootNode, BAD_CAST CLASS, class_val);
+        xmlSetProp(rootNode, BAD_CAST FUNCTION, function);
     }
-    if(class)
-        g_free(class);
+    if(class_val)
+        xmlFree(class_val);
     if(function)
-        g_free(function);
+        xmlFree(function);
   
     init_status = initialization(&remixmid, &remixsid);
     attempts = 0;
@@ -322,16 +321,14 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
     char* tmp = NULL;
     char* url;
     //gchar* class = get_req_class(reqXml);
-    gchar* function = get_req_function(reqXml);
+    xmlChar* function = get_req_function(reqXml);
     int num = 0;
     int init_status = 0;
 
     url = make_url(reqXml, remixmid, remixsid);
 
-    xmlNodePtr rootNode;
-
-    if (url == NULL || strlen(url)  < 1 ) {
-        if (g_strcmp0(function, GET_BINARY_DATA) == 0 ) {
+    if (url == NULL || strlen(url) < 1) {
+        if (g_strcmp0((gchar *)function, GET_BINARY_DATA) == 0 ) {
             counter = -1;
             g_free(function);
             return 0;
@@ -344,7 +341,7 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
     int code = 0;
     code = http_get(url, info_proxy, info_port, NULL, &tmp);
     if (code == 200) {
-        if (g_strcmp0(function, GET_BINARY_DATA) == 0 ) {
+        if (g_strcmp0((gchar *)function, GET_BINARY_DATA) == 0 ) {
             g_free(function);
             if (counter == -1) {
                 return 0;
@@ -353,33 +350,40 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
             g_free(url);
             g_free(tmp);
             counter++;
-            make_request( reqXml, doc, remixmid, remixsid);
+            make_request(reqXml, doc, remixmid, remixsid);
             return 0;
         }
         g_free(url);
         switch (check(tmp)) {
             case 0:
-                if (g_strcmp0(function, SEND_MESSAGE) == 0) {
+                if (g_strcmp0((gchar *)function, SEND_MESSAGE) == 0) {
                     info_message(DRV_MESS_ERROR_CODE, doc, DRV_MESS_ERROR, 1);
 		    g_free(tmp);
-                    g_free(function);
+                    xmlFree(function);
+                    return 0;
+                }
+                if (g_strcmp0((gchar *)function, DELETE_MESSAGE) == 0) {
+                    info_message(DRV_MESS_DEL_ERROR_CODE, doc, DRV_MESS_DEL_ERROR, 1);
+                    g_free(tmp);
+                    xmlFree(function);
                     return 0;
                 }
             case 1:
 
-                if (g_strcmp0(function, GET_MY_PROFILE) == 0 || g_strcmp0(function, UPDATE_PROFILE) == 0) {
+                if (g_strcmp0((gchar *)function, GET_MY_PROFILE) == 0 || 
+                    g_strcmp0((gchar *)function, UPDATE_PROFILE) == 0) {
                     if(parser_profile(doc, tmp, remixmid) == 1){
                         info_message(DRV_RESP_ERROR_CODE, doc, DRV_RESP_ERROR, 1);
                     }
                     g_free(tmp);      	    
                 }
-                if (g_strcmp0(function, SEND_MY_PROFILE) == 0) {
+                if (g_strcmp0((gchar *)function, SEND_MY_PROFILE) == 0) {
                     info_message(DRV_PROF_SAVED_CODE, doc, DRV_PROF_SAVED, 0);
                     g_free(tmp);
-                    g_free(function);
+                    xmlFree(function);
                     return 0;
                 }
-                if (g_strcmp0(function, GET_LIST_FRIENDS) == 0) {
+                if (g_strcmp0((gchar *)function, GET_LIST_FRIENDS) == 0) {
                     converted_friends = g_convert(tmp, -1, UTF8, CP1251, NULL, NULL, NULL);
                     g_free(tmp);
                     num = parser_friends(converted_friends, doc);
@@ -388,22 +392,24 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
                         counter++;
                         make_request( reqXml, doc, remixmid, remixsid);
                     } else {
-                        g_free(function);
+                        xmlFree(function);
                         return 0;
                     }
                 }
-                if (g_strcmp0(function, UPDATE_INBOX_MESSAGES) == 0 || g_strcmp0(function, UPDATE_OUTBOX_MESSAGES) == 0) {
+                if (g_strcmp0((gchar *)function, UPDATE_INBOX_MESSAGES) == 0 || 
+                    g_strcmp0((gchar *)function, UPDATE_OUTBOX_MESSAGES) == 0) {
                     num = parser_messages(tmp, doc);
                     g_free(tmp);
                     if (num == PAGE_SIZE && counter < MAX_COUNTER) {
+                        g_debug("num_messages = %d", num);
                         counter++;
                         make_request( reqXml, doc, remixmid, remixsid);
                     } else {
-                        g_free(function);
+                        xmlFree(function);
                         return 0;
                     }
                 }
-                if (g_strcmp0(function, GET_NEW_MESSAGES) == 0) {
+                if (g_strcmp0((gchar *)function, GET_NEW_MESSAGES) == 0) {
                     g_debug("GET_NEW_MESSAGES");
                     num = parser_new_messages(tmp);
                     g_free(tmp);
@@ -422,14 +428,28 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
                     }
                 }
 
-                if (g_strcmp0(function, SEND_MESSAGE) == 0) {
+                if (g_strcmp0((gchar *)function, SEND_MESSAGE) == 0) {
                     info_message(DRV_MESS_SEND_CODE, doc, DRV_MESS_SEND, 0);
                     g_free(tmp);
                     g_free(function);
                     return 0;
                 }
+                if (g_strcmp0((gchar *)function, DELETE_MESSAGE) == 0) {
+                    info_message(DRV_MESS_DEL_CODE, doc, DRV_MESS_DEL, 0);
+                    g_free(tmp);
+                    g_free(function);
+                    return 0;
+                }
                 g_free(function);
                 break;
+            case 5:
+                if (g_strcmp0((gchar *)function, DELETE_FRIEND) == 0) {
+                    info_message(DRV_FRIEND_DEL_CODE, doc, DRV_FRIEND_DEL, 0);
+                    g_free(tmp);
+                    g_free(function);
+                    return 0;
+                }
+                break;
             case -1:
                 unset_settings(REMIXSID);
                 if (attempts == 0) {
@@ -547,7 +567,7 @@ int get_settings(xmlDocPtr doc)
     gchar* path;
     gchar* tmp;
     gint status = 0, autoupdate = 0;
-    xmlNodePtr rootNode, childNode, node;
+    xmlNodePtr rootNode, childNode;
     
     rootNode = xmlDocGetRootElement(doc);
     rootNode = rootNode->children;
@@ -570,25 +590,25 @@ int get_settings(xmlDocPtr doc)
     autoupdate = gconf_client_get_int (client, path , NULL);
     g_free(path);
     
-    childNode = xmlNewDocNode(doc, NULL, BAD_CAST STRING, login);
-    xmlSetProp(childNode, NAME, LOGIN);
+    childNode = xmlNewDocNode(doc, NULL, BAD_CAST STRING, BAD_CAST login);
+    xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST LOGIN);
     childNode = xmlAddChild(rootNode, childNode);
     g_free(login);
 
-    childNode = xmlNewDocNode(doc, NULL, BAD_CAST STRING, password);
-    xmlSetProp(childNode, NAME, PASSWORD);
+    childNode = xmlNewDocNode(doc, NULL, BAD_CAST STRING, BAD_CAST password);
+    xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST PASSWORD);
     childNode = xmlAddChild(rootNode, childNode);
     g_free(password);
 
-    tmp = g_strdup_printf("%d",autoupdate);
-    childNode = xmlNewDocNode(doc, NULL, BAD_CAST NUMBER, tmp);
-    xmlSetProp(childNode, NAME, AUTOUPDATE);
+    tmp = g_strdup_printf("%d", autoupdate);
+    childNode = xmlNewDocNode(doc, NULL, BAD_CAST NUMBER, BAD_CAST tmp);
+    xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST AUTOUPDATE);
     childNode = xmlAddChild(rootNode, childNode);
     g_free(tmp);
     
-    tmp = g_strdup_printf("%d",status);
-    childNode = xmlNewDocNode(doc, NULL, BAD_CAST BOOLEAN, tmp);
-    xmlSetProp(childNode, NAME, STATUS);
+    tmp = g_strdup_printf("%d", status);
+    childNode = xmlNewDocNode(doc, NULL, BAD_CAST BOOLEAN, BAD_CAST tmp);
+    xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST STATUS);
     childNode = xmlAddChild(rootNode, childNode);
     g_free(tmp);
 
@@ -612,9 +632,9 @@ int set_settings (xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info)
     gboolean checked = 1;
     int status = 0;
     gchar* path;
-    gchar* temp;
-    gchar* name;
-    xmlNodePtr rootNode, childNode, node;
+    xmlChar* temp;
+    xmlChar* name;
+    xmlNodePtr rootNode;
 
     client = gconf_client_get_default ();
     rootNode = xmlDocGetRootElement(reqXml);
@@ -623,50 +643,54 @@ int set_settings (xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info)
 
     while(rootNode != NULL) {
         g_debug("%s", rootNode->name);
-        name = xmlGetProp(rootNode, NAME);
-        if (g_strcmp0(name, LOGIN) == 0) {
+        name = xmlGetProp(rootNode, BAD_CAST NAME);
+        if (g_strcmp0((gchar *)name, LOGIN) == 0) {
             path = g_strconcat(PATH, LOGIN, NULL);
             temp = xmlNodeGetContent(rootNode);	    
-            checked = gconf_client_set_string (client, path, temp, NULL);
+            checked = gconf_client_set_string (client, path, (gchar *)temp, NULL);
             g_free(path);    
-	    g_free(temp);
+	    xmlFree(temp);
         }
-        g_free(name);
-        name = xmlGetProp(rootNode, NAME);
-        if (g_strcmp0(name, PASSWORD) == 0) {
+        xmlFree(name);
+        
+        name = xmlGetProp(rootNode, BAD_CAST NAME);
+        if (g_strcmp0((gchar *)name, PASSWORD) == 0) {
             path = g_strconcat(PATH, PASSWORD, NULL);
 	    temp = xmlNodeGetContent(rootNode);
-            checked = gconf_client_set_string (client, path, temp, NULL);
+            checked = gconf_client_set_string (client, path, (gchar *)temp, NULL);
             g_free(path);
-	    g_free(temp);
+	    xmlFree(temp);
         }
-        g_free(name);
-        name = xmlGetProp(rootNode, NAME);
-        if (g_strcmp0(name, AUTOUPDATE) == 0) {
+        xmlFree(name);
+        
+        name = xmlGetProp(rootNode, BAD_CAST NAME);
+        if (g_strcmp0((gchar *)name, AUTOUPDATE) == 0) {
             int time = 0;
-	    temp = (char*)xmlNodeGetContent(rootNode);
-            time = atoi(temp);
+	    temp = xmlNodeGetContent(rootNode);
+            time = atoi((gchar *)temp);
             path = g_strconcat(PATH, AUTOUPDATE, NULL);
             checked = gconf_client_set_int (client, path, time, NULL);
 #ifndef TEST
 	    init_event_manager(time);
 #endif   
             g_free(path);
-	    g_free(temp);
+	    xmlFree(temp);
         }
-        g_free(name);
-        name = xmlGetProp(rootNode, NAME);
-        if (g_strcmp0(name, STATUS) == 0) {
+        xmlFree(name);
+        
+        name = xmlGetProp(rootNode, BAD_CAST NAME);
+        if (g_strcmp0((gchar *)name, STATUS) == 0) {
             path = g_strconcat(PATH, STATUS, NULL);
 	    temp = xmlNodeGetContent(rootNode);
 #ifndef TEST
-            info->status = atoi(temp);
+            info->status = atoi((gchar *)temp);
 #endif
-            checked = gconf_client_set_int (client, path, atoi(temp), NULL);
+            checked = gconf_client_set_int (client, path, atoi((gchar *)temp), NULL);
             g_free(path);
-	    g_free(temp);
+	    xmlFree(temp);
         }
-        g_free(name);
+        xmlFree(name);
+        
         rootNode = rootNode->next;
         if(!checked)
             status = 1;
@@ -707,13 +731,9 @@ void unset_settings(char* name){
  */
 int authorize(char *email, char *pass)
 {
-    FILE* fpin;
-    int i;
-    char *head, *body;
-    char url[URL_SIZE];
+    char *body;
     char* mid = NULL, sid[MID_SIZE];
     char *tmp;
-    char *resp;
     gchar* post_data;
     int code = 0;
     struct curl_slist *cookies;
@@ -890,13 +910,13 @@ int authorize(char *email, char *pass)
  * @param reqXml - request
  * @return class of request.
  */
-char* get_req_class(xmlDocPtr reqXml)
+xmlChar* get_req_class(xmlDocPtr reqXml)
 {
     xmlNodePtr rootNode = NULL;
     if(reqXml != NULL)
         rootNode = xmlDocGetRootElement(reqXml);
     if (rootNode != NULL)
-        return xmlGetProp(rootNode, CLASS);
+        return xmlGetProp(rootNode, BAD_CAST CLASS);
     return NULL;
 }
 
@@ -906,37 +926,46 @@ char* get_req_class(xmlDocPtr reqXml)
  * @param reqXml - request
  * @return function of request.
  */
-char* get_req_function(xmlDocPtr reqXml)
+xmlChar* get_req_function(xmlDocPtr reqXml)
 {
     xmlNodePtr rootNode = NULL;
     if (reqXml != NULL)
 	rootNode = xmlDocGetRootElement(reqXml);
     if (rootNode != NULL)
-	return xmlGetProp(rootNode, FUNCTION);
+	return xmlGetProp(rootNode, BAD_CAST FUNCTION);
     return NULL;
 }
 
+/**
+ * Set message status = read
+ *
+ * @param reqXml - request
+ * @param remixmid - user id 
+ * @param remixsid - session remixmid
+ * @return 0 on success or 1 other.
+ */
 int read_message(xmlDocPtr reqXml, char* remixmid, char* remixsid)
 {
     g_debug("read_message START");
     xmlXPathObject *Obj;
     xmlNodePtr node, node2;
-    char *id;
+    xmlChar *id;
     char *url;
     char *tmp;
     Obj = xpath("//Response/Params/array/struct", reqXml);
     if (Obj != NULL) {
 	node = Obj->nodesetval->nodeTab[0];
 	for(node2 = node; node2 != NULL; node2 = node2->next) {
-            id = xmlGetProp(node2, "id");
-            url = g_strdup_printf("http://userapi.com/data?act=history&id=%s&read=%s_&sid=%s", remixmid, id+2, remixsid);
-            http_get(url, info_proxy, info_port, NULL, &tmp );
+            id = xmlGetProp(node2, BAD_CAST "id");
+            url = g_strdup_printf("http://userapi.com/data?act=history&id=%s&read=%s_&sid=%s", remixmid, (gchar *)id + 2, remixsid);
+            http_get(url, info_proxy, info_port, NULL, &tmp);
             g_free(url);
-	    g_debug("%s",tmp);
+	    g_debug("%s", tmp);
+	    xmlFree(id);
 	}
 	return 0;
     }
-				
+    return 1;
 }
 /**
  * Buil url for request
@@ -946,10 +975,10 @@ int read_message(xmlDocPtr reqXml, char* remixmid, char* remixsid)
  * @param remixmid - authorization parameter
  * @return function of request.
  */
-char* make_url(xmlDocPtr reqXml, char* remixmid, char* remixsid)
+gchar* make_url(xmlDocPtr reqXml, char* remixmid, char* remixsid)
 {
     g_debug("make_url START");
-    char* url;
+    xmlChar* url;
     const char* params[7];
     xmlDocPtr urlXml;
     xmlNodePtr root;
@@ -965,18 +994,21 @@ char* make_url(xmlDocPtr reqXml, char* remixmid, char* remixsid)
 
     xsltStylesheetPtr cur = NULL;
 
-    cur = xsltParseStylesheetFile(XSL_URL);
+    cur = xsltParseStylesheetFile(BAD_CAST XSL_URL);
 
     if(cur != NULL && reqXml != NULL) {
         urlXml = xsltApplyStylesheet(cur, reqXml, params);
         //xmlDocDump(stdout, urlXml);
     } else 
 	return NULL;
+
     if (urlXml == NULL)
         return NULL;
+
     root = xmlDocGetRootElement(urlXml);
     if (root == NULL)
         return NULL;
+
     url = xmlNodeGetContent(root);
     
     xsltFreeStylesheet(cur);    
@@ -987,9 +1019,11 @@ char* make_url(xmlDocPtr reqXml, char* remixmid, char* remixsid)
     g_free((gpointer*)params[3]);
     g_free((gpointer*)params[4]);
     g_free((gpointer*)params[5]);
-    g_printf("%s",url);
+
+    g_printf("%s", url);
     g_debug("make_url END");
-    return url;
+
+    return (gchar *)url;
 }
 
 
@@ -1005,40 +1039,40 @@ char* make_url(xmlDocPtr reqXml, char* remixmid, char* remixsid)
 int info_message(char* code, xmlDocPtr doc, char* message, int type)
 {
     xmlNodePtr rootNode, node, childNode;
-    rootNode = xmlNewDocNode(doc, NULL,  "Response", NULL);
+    rootNode = xmlNewDocNode(doc, NULL, BAD_CAST "Response", NULL);
     xmlDocSetRootElement(doc, rootNode);
 
-    xmlSetProp(rootNode, CLASS, "systemMessages");
+    xmlSetProp(rootNode, BAD_CAST CLASS, BAD_CAST "systemMessages");
 
     if (type == 1)
-        xmlSetProp(rootNode, FUNCTION, "errorMessage");
+        xmlSetProp(rootNode, BAD_CAST FUNCTION, BAD_CAST "errorMessage");
     else if (type == 0)
-        xmlSetProp(rootNode, FUNCTION, "infoMessage");
+        xmlSetProp(rootNode, BAD_CAST FUNCTION, BAD_CAST "infoMessage");
     else if (type == 2)
-        xmlSetProp(rootNode, FUNCTION, "captchaMessage");
+        xmlSetProp(rootNode, BAD_CAST FUNCTION, BAD_CAST "captchaMessage");
     else
         return 1;
 
-    node = xmlNewDocNode(doc, NULL,   PARAMS,  NULL);
+    node = xmlNewDocNode(doc, NULL, BAD_CAST PARAMS, NULL);
     childNode = xmlAddChild(rootNode, node);
 
-    node = xmlNewDocNode(doc, NULL,   STRING,  DRIVER_NAME);
-    xmlSetProp(node, NAME, "moduleName");
+    node = xmlNewDocNode(doc, NULL, BAD_CAST STRING, BAD_CAST DRIVER_NAME);
+    xmlSetProp(node, BAD_CAST NAME, BAD_CAST "moduleName");
     node = xmlAddChild(childNode, node);
 
-    node = xmlNewDocNode(doc, NULL,   STRING,  code);
-    xmlSetProp(node, NAME, "code");
+    node = xmlNewDocNode(doc, NULL, BAD_CAST STRING, BAD_CAST code);
+    xmlSetProp(node, BAD_CAST NAME, BAD_CAST "code");
     node = xmlAddChild(childNode, node);
 
-    node = xmlNewDocNode(doc, NULL,   STRING,  message);
-    xmlSetProp(node, NAME, "text");
+    node = xmlNewDocNode(doc, NULL, BAD_CAST STRING, BAD_CAST message);
+    xmlSetProp(node, BAD_CAST NAME, BAD_CAST "text");
     node = xmlAddChild(childNode, node);
     return 0;
 }
 
 int captcha_message(xmlDocPtr doc, xmlDocPtr reqXml)
 {
-    guint32 cpatcha_sid = g_random_int_range(1,1000);
+    guint32 cpatcha_sid = g_random_int_range(1, 1000);
     char* captcha_image;
     captcha_image = get_captcha(cpatcha_sid);
     info_message("403", doc, DRV_CAPT_ERROR, 2);
@@ -1048,12 +1082,12 @@ int captcha_message(xmlDocPtr doc, xmlDocPtr reqXml)
     Obj = xpath("//Response/Params", doc);
     node_param = Obj->nodesetval->nodeTab[0];
 
-    node = xmlNewDocNode(doc, NULL,   IMG, captcha_image);
-    xmlSetProp(node, NAME, "Img");
+    node = xmlNewDocNode(doc, NULL, BAD_CAST IMG, BAD_CAST captcha_image);
+    xmlSetProp(node, BAD_CAST NAME, BAD_CAST "Img");
     node = xmlAddChild(node_param, node);
 
-    node = xmlNewDocNode(doc, NULL, STRING, NULL);
-    xmlSetProp(node, NAME, "oldRequest");
+    node = xmlNewDocNode(doc, NULL, BAD_CAST STRING, NULL);
+    xmlSetProp(node, BAD_CAST NAME, BAD_CAST "oldRequest");
     node = xmlAddChild(node_param, node);
 
     rootNode = xmlDocGetRootElement(reqXml);
@@ -1067,20 +1101,25 @@ int captcha_message(xmlDocPtr doc, xmlDocPtr reqXml)
     if (node_param == NULL)
         g_debug("node_param == NULL");
     else {
+	gchar *str_sid = g_strdup_printf("%d", cpatcha_sid);
+
         Obj = xpath("//Response/Params/string[@name='oldRequest']/Request/Params/string[@name='fcsid']", doc);
         if (Obj->nodesetval->nodeNr != 0) {
             node = Obj->nodesetval->nodeTab[0];
-            xmlNodeSetContent(node, g_strdup_printf("%d",cpatcha_sid));
+            xmlNodeSetContent(node, BAD_CAST str_sid);
         } else {
-            node = xmlNewDocNode(doc, NULL, STRING, g_strdup_printf("%d",cpatcha_sid));
-            xmlSetProp(node, NAME, "fcsid");
+            node = xmlNewDocNode(doc, NULL, BAD_CAST STRING, BAD_CAST str_sid);
+            xmlSetProp(node, BAD_CAST NAME, BAD_CAST "fcsid");
             node = xmlAddChild(node_param, node);
         
-            node = xmlNewDocNode(doc, NULL, STRING, NULL);
-            xmlSetProp(node, NAME, "fccode");
+            node = xmlNewDocNode(doc, NULL, BAD_CAST STRING, NULL);
+            xmlSetProp(node, BAD_CAST NAME, BAD_CAST "fccode");
             node = xmlAddChild(node_param, node);
         }
+
+        g_free(str_sid);
     }
+    
     return 0;
 }
 
@@ -1099,7 +1138,7 @@ int http_get(const char* url, const char* proxy, long port, char** header, char*
     CURL* c;
     CURLcode code;
     char* type2;
-    struct MemoryStruct chunk,chunk2;
+    struct MemoryStruct chunk, chunk2;
     
     chunk.memory = NULL; 
     chunk.size = 0;
@@ -1124,7 +1163,7 @@ int http_get(const char* url, const char* proxy, long port, char** header, char*
     g_debug("send request");
 
     if (curl_easy_perform(c) != 0) {
-        fprintf(stderr, "Can't perform the request\n");
+        g_warning("Can't perform the request\n");
         curl_easy_cleanup(c);
         return 400;
     }
@@ -1147,9 +1186,9 @@ int http_get(const char* url, const char* proxy, long port, char** header, char*
 
     if (body != NULL) {
         if (g_strcmp0(type2, "image/jpeg") == 0) {
-            *body = g_base64_encode (chunk.memory, chunk.size);
+            *body = g_base64_encode(chunk.memory, chunk.size);
         } else {
-        *body = g_strdup(chunk.memory);
+    	    *body = g_strdup(chunk.memory);
         }
     }
     if(chunk.memory)
@@ -1181,7 +1220,6 @@ int http_post(const char* url, const char* proxy, long port, char* post_data, ch
     CURL* c;
     CURLcode code;
     CURLcode res;
-    char* type2;
     struct MemoryStruct chunk,chunk2;
 
     chunk.memory = NULL;
@@ -1204,6 +1242,7 @@ int http_post(const char* url, const char* proxy, long port, char* post_data, ch
     curl_easy_setopt(c, CURLOPT_POST, 1);
     curl_easy_setopt(c, CURLOPT_POSTFIELDS, post_data);
     curl_easy_setopt(c, CURLOPT_POSTFIELDSIZE, -1);
+    curl_easy_setopt(c, CURLOPT_FOLLOWLOCATION, 1);
 
     curl_easy_setopt(c, CURLOPT_COOKIEFILE, "");
 
@@ -1215,7 +1254,7 @@ int http_post(const char* url, const char* proxy, long port, char* post_data, ch
     g_debug("send request");
     
     if (curl_easy_perform(c) != 0) {
-        fprintf(stderr, "Can't perform the request\n");
+        g_warning("Can't perform the request\n");
         curl_easy_cleanup(c);
         return 400;
     }
