@@ -1,8 +1,8 @@
 /*
- * module.h - interface for module developers
- * This file is part of MSA program
+ * mysociasl_driver.h - interface for module developers
+ * This file is part of MySocials program
  *
- * Copyright (C) 2009 - Alexander V. Borodin
+ * Copyright (C) 2009, 2010 - Alexander V. Borodin
  *
  * MSA program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
  * Boston, MA  02110-1301  USA
  */
 
-#ifndef _MSA_MODULE_H_
-#define _MSA_MODULE_H_
+#ifndef _MYSOCIALS_DRIVER_H_
+#define _MYSOCIALS_DRIVER_H_
 
 #include <glib.h>
 
@@ -76,57 +76,6 @@
 
 #define TARGET_NODE "TargetID"
 
-/* Error Code */
-typedef enum error_type
-{
-    FAILURE = -1,
-    NO_ERRORS = 0,
-    SUCCESS = 0,
-    ERROR_ALLOCATION_OF_MEMORY,
-    ERROR_NO_DRIVER_FUNCTION,
-    ERROR_INITIALIZATION_ALREADY_PASSED,
-    ERROR_DRIVER_IS_BUSY,
-    ERROR_CANT_SEND_DATA,
-    ERROR_CANT_PARSE_DATA
-} error_type ;
-/** db message code **/
-//#define DB_SAVE_ERROR_PROFILE_CODE "300"
-//#define DB_SAVE_MESSAGE_PROFILE_CODE "301"
-//#define DB_GET_ERROR_PROFILE_CODE "302"
-//#define DB_SAVE_MESSAGE_FRIENDS_CODE "310"
-//#define DB_SAVE_ERROR_FRIENDS_CODE "311"
-//#define DB_GET_ERROR_FRIENDS_CODE "312"
-//#define DB_SAVE_MESSAGE_FRIENDS_PROFILE_CODE "313"
-//#define DB_SAVE_ERROR_FRIENDS_PROFILE_CODE "314"
-//#define DB_GET_ERROR_BINARY_CODE "321"
-//#define DB_SAVE_ERROR_BINARY_CODE "322"
-//#define DB_GET_ERROR_INBOX_MESSAGES_CODE "331"
-//#define DB_GET_ERROR_OUTBOX_MESSAGES_CODE "332"
-//#define DB_UPDATE_MESSAGE_INBOX_MESSAGES_CODE "333"
-//#define DB_UPDATE_MESSAGE_OUTBOX_MESSAGES_CODE "334"
-//#define DB_GET_ERROR_INBOX_MESSAGE_CODE "335"
-//#define DB_NEW_INBOX_MESSAGES_CODE "341"
-//#define DB_INIT_ERROR_CODE "351"
-
-/** db message text **/
-//#define DB_SAVE_MESSAGE_PROFILE_TEXT "profile updated"
-//#define DB_SAVE_ERROR_PROFILE_TEXT "profile wasn't updated"
-//#define DB_GET_ERROR_PROFILE_TEXT "profile wasn't found"
-//#define DB_SAVE_MESSAGE_FRIENDS_TEXT "friends list updated"
-//#define DB_SAVE_ERROR_FRIENDS_TEXT "friends list wasn't updated"
-//#define DB_GET_ERROR_FRIENDS_TEXT "friends list wasn't found"
-//#define DB_SAVE_MESSAGE_FRIENDS_PROFILE_TEXT "friend's profile updated"
-//#define DB_SAVE_ERROR_FRIENDS_PROFILE_TEXT "friend's profile wasn't updated"
-//#define DB_GET_ERROR_BINARY_TEXT "image wasn't found"
-//#define DB_SAVE_ERROR_BINARY_TEXT "image wasn't updated"
-//#define DB_GET_ERROR_INBOX_MESSAGES_TEXT "inbox messages list wasn't saved" 
-//#define DB_GET_ERROR_OUTBOX_MESSAGES_TEXT "outbox messages list wasn't saved" 
-//#define DB_UPDATE_MESSAGE_INBOX_MESSAGES_TEXT "inbox messages list saved" 
-//#define DB_UPDATE_MESSAGE_OUTBOX_MESSAGES_TEXT "outbox messages list was saved" 
-//#define DB_GET_ERROR_INBOX_MESSAGE_TEXT "inbox messages list wasn't found"
-//#define DB_NEW_INBOX_MESSAGES_TEXT "new messages:"
-//#define DB_INIT_ERROR_TEXT "db critical error"
-
 /** Driver message code **/
 #define DRV_SETT_ERROR_CODE "409"
 #define DRV_SETT_SAVED_CODE "410"
@@ -140,20 +89,156 @@ typedef enum error_type
 #define DRV_MESS_ERROR_CODE "405"
 #define DRV_ACCESS_ERROR_CODE "406"
 #define DRV_SERVER_ERROR_CODE "411"
+#define DRV_MESS_DEL_ERROR_CODE "412"
+#define DRV_MESS_DEL_CODE "413"
+#define DRV_FRIEND_DEL_CODE "414"
 
 /** Driver message text **/
 #define DRV_SETT_ERROR "Unable to save settings"
+#define L10N_DRV_SETT_ERROR _("Unable to save settings")
+
 #define DRV_SETT_SAVED "Settings saved"
+#define L10N_DRV_SETT_SAVED _("Settings saved")
+
 #define DRV_AUTH_ERROR "Authorization problem"
+#define L10N_DRV_AUTH_ERROR _("Authorization problem")
+
 #define DRV_REQ_ERROR "Unable to perform request"
+#define L10N_DRV_REQ_ERROR _("Unable to perform request")
+
 #define DRV_PROF_SAVED "Profile changed"
+#define L10N_DRV_PROF_SAVED _("Profile changed")
+
 #define DRV_CAPT_ERROR "Captcha"
+#define L10N_DRV_CAPT_ERROR _("Captcha")
+
 #define DRV_RESP_ERROR "Bad response from server"
+#define L10N_DRV_RESP_ERROR _("Bad response from server")
+
 #define DRV_NETW_ERROR "Network problem"
+#define L10N_DRV_NETW_ERROR _("Network problem")
+
 #define DRV_MESS_SEND "Message send"
+#define L10N_DRV_MESS_SEND _("Message send")
+
 #define DRV_MESS_ERROR "Unable send message"
+#define L10N_DRV_MESS_ERROR _("Unable send message")
+
 #define DRV_ACCESS_ERROR "Operation prohibited by privacy"
+#define L10N_DRV_ACCESS_ERROR _("Operation prohibited by privacy")
+
 #define DRV_SERVER_ERROR "Internal Server Error"
+#define L10N_DRV_SERVER_ERROR _("Internal Server Error")
+
+#define DRV_MESS_DEL_ERROR "Can't delete message"
+#define L10N_DRV_MESS_DEL_ERROR _("Can't delete message")
+
+#define DRV_MESS_DEL "Message deleted"
+#define L10N_DRV_MESS_DEL _("Message deleted")
+
+#define DRV_FRIEND_DEL "Friend deleted"
+#define L10N_DRV_FRIEND_DEL _("Friend deleted")
+
+/* Entity names */
+#define FIRST_NAME "FirstName"
+#define L10N_FIRST_NAME _("FirstName")
+
+#define LAST_NAME "LastName"
+#define L10N_LAST_NAME _("LastName")
+
+#define CITY_NAME "CityName"
+#define L10N_CITY_NAME _("CityName")
+
+#define COUNTRY_NAME "CountryName"
+#define L10N_COUNTRY_NAME _("CountryName")
+
+#define BIRTHDAY_NAME "Birthday"
+#define L10N_BIRTHDAY_NAME _("Birthday")
+
+#define GENDER_NAME "Gender"
+#define L10N_GENDER_NAME _("Gender")
+
+#define FAMILY_STATE_NAME "FamilyState"
+#define L10N_FAMILY_STATE_NAME _("FamilyState")
+
+#define POLITICAL_VIEW_NAME "PoliticalView"
+#define L10N_POLITICAL_VIEW_NAME _("PoliticalView")
+
+/* Entity values */
+#define MALE "male"
+#define L10N_MALE _("male")
+
+#define FEMALE "female"
+#define L10N_FEMALE _("female")
+
+#define NO_MALE "none"
+#define L10N_NO_MALE _("none")
+
+#define FAMILY_STATE_1 "single"
+#define L10N_FAMILY_STATE_1 _("single")
+
+#define FAMILY_STATE_2 "in a relationship"
+#define L10N_FAMILY_STATE_2 _("in a relationship")
+
+#define FAMILY_STATE_3 "engaged"
+#define L10N_FAMILY_STATE_3 _("engaged")
+
+#define FAMILY_STATE_4 "married"
+#define L10N_FAMILY_STATE_4 _("married")
+
+#define FAMILY_STATE_5 "it is complicated"
+#define L10N_FAMILY_STATE_5 _("it is complicated")
+
+#define FAMILY_STATE_6 "actively searching"
+#define L10N_FAMILY_STATE_6 _("actively searching")
+
+#define FAMILY_STATE_0 "none"
+#define L10N_FAMILY_STATE_0 _("none")
+
+#define POL_VIEW_1 "Communist"
+#define L10N_POL_VIEW_1 _("Communist")
+
+#define POL_VIEW_2 "Socialist"
+#define L10N_POL_VIEW_2 _("Socialist")
+
+#define POL_VIEW_3 "Moderate"
+#define L10N_POL_VIEW_3 _("Moderate")
+
+#define POL_VIEW_4 "Liberal"
+#define L10N_POL_VIEW_4 _("Liberal")
+
+#define POL_VIEW_5 "Conservative"
+#define L10N_POL_VIEW_5 _("Conservative")
+
+#define POL_VIEW_6 "Monarchist"
+#define L10N_POL_VIEW_6 _("Monarchist")
+
+#define POL_VIEW_7 "Ultraconservative"
+#define L10N_POL_VIEW_7 _("Ultraconservative")
+
+#define POL_VIEW_8 "Apathetic"
+#define L10N_POL_VIEW_8 _("Apathetic")
+
+#define POL_VIEW_0 "none"
+#define L10N_POL_VIEW_0 _("none")
+
+
+#ifndef _MSA_MODULE
+#define _MSA_MODULE
+
+/* Error Code */
+typedef enum error_type
+{
+    FAILURE = -1,
+    NO_ERRORS = 0,
+    SUCCESS = 0,
+    ERROR_ALLOCATION_OF_MEMORY,
+    ERROR_NO_DRIVER_FUNCTION,
+    ERROR_INITIALIZATION_ALREADY_PASSED,
+    ERROR_DRIVER_IS_BUSY,
+    ERROR_CANT_SEND_DATA,
+    ERROR_CANT_PARSE_DATA
+} error_type;
 
 /** @enum msa_module_type
  *  @brief List of module types
@@ -261,6 +346,6 @@ typedef struct _msa_module {
     int (*shutdown)();
 
 } msa_module;
-
+#endif /*_MSA_MODULE*/
 
 #endif
