@@ -72,7 +72,7 @@ int check(char* json)
             //Get server response status
             buf = json_object_object_get(status, "ok" );
             if(buf != NULL) {
-                g_debug("read ok status");
+                g_debug("read ok status = %d", json_object_get_int(buf));
 		check_status = json_object_get_int(buf);
                 json_object_put(status);
                 return check_status;
@@ -99,18 +99,19 @@ int parser_image(xmlDocPtr doc, char* data, char* url)
     if (rootNode != NULL) {
         rootNode = rootNode->children;           //params
 
-        childNode = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_IMG, data);
+        childNode = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_IMG, BAD_CAST data);
         //g_free(data);
 	//TODO
 	//Save file on disk
 	//insert name of file
-        xmlSetProp(childNode, NAME, "Img");
-        xmlSetProp(childNode, "uri", url);
+        xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST "Img");
+        xmlSetProp(childNode, BAD_CAST "uri", BAD_CAST url);
         xmlAddChild(rootNode, childNode);
-        xmlDocDump(stdout,doc);
+        //xmlDocDump(stdout, doc);
         return 0;
-    } else
-        return 1;
+    }
+
+    return 1;
 }
 /**
  * Parses json data, form xml profile
@@ -121,13 +122,11 @@ int parser_image(xmlDocPtr doc, char* data, char* url)
  */
 int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
 {
-    int i = 0, j = 0, buf_serialized = 0;
-    char* file_name;
+    int i = 0, buf_serialized = 0;
     gchar* id = NULL;
     struct json_object* buf, *profile, *ht, *edu,*edu_item;
     
     xmlNodePtr rootNode, childNode, node, node2;
-    xmlAttrPtr attr;
 
     rootNode = xmlDocGetRootElement(doc);     //response 
     rootNode = rootNode->children;           //params
@@ -140,7 +139,7 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
         //PARSE FRIEND'S ID
         if (strcmp(remixmid, json_object_get_string(buf)) != 0 ) {
             id = g_strconcat(PREFIX, json_object_get_string(buf), NULL);
-            xmlSetProp(rootNode, "id", id);
+            xmlSetProp(rootNode, BAD_CAST "id", BAD_CAST id);
             g_free(id);
         }
         //json_object_put(buf);
@@ -149,8 +148,8 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
         buf = json_object_object_get(profile, FIRST_NAME_KEY );
         if(buf == NULL)
             return 1;
-        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, json_object_get_string(buf));
-        xmlSetProp(node, NAME, "FirstName");
+        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST json_object_get_string(buf));
+        xmlSetProp(node, BAD_CAST NAME, BAD_CAST FIRST_NAME);
         node = xmlAddChild(rootNode, node);
         //json_object_put(buf);
 
@@ -158,8 +157,8 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
         buf = json_object_object_get(profile, LAST_NAME_KEY );
         if(buf == NULL)
             return 1;
-        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, json_object_get_string(buf));
-        xmlSetProp(node, NAME, "LastName");
+        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST json_object_get_string(buf));
+        xmlSetProp(node, BAD_CAST NAME, BAD_CAST LAST_NAME);
         node = xmlAddChild(rootNode, node);
         //json_object_put(buf);
 	
@@ -169,9 +168,9 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
             return 1;
         char* img;
         if(http_get(json_object_get_string(buf), info_proxy, info_port, NULL, &img) == 200) {
-            node = xmlNewDocNode(doc, NULL,  BAD_CAST "img", img);
-            xmlSetProp(node, NAME, "Img");
-            xmlSetProp(node, "uri", json_object_get_string(buf));
+            node = xmlNewDocNode(doc, NULL,  BAD_CAST "img", BAD_CAST img);
+            xmlSetProp(node, BAD_CAST NAME, BAD_CAST "Img");
+            xmlSetProp(node, BAD_CAST "uri", BAD_CAST json_object_get_string(buf));
             node = xmlAddChild(rootNode, node);
             g_debug("set image");
 	    free(img);
@@ -184,65 +183,87 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
             return 1;
         //PARSE CITY
         childNode = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_STRUCT, NULL );
-        xmlSetProp(childNode, NAME, "City");
+        xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST "City");
         childNode = xmlAddChild(rootNode, childNode);
 
         buf = json_object_object_get(ht, CITY_ID_KEY);
-        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, json_object_get_string(buf) );
-        xmlSetProp(node, NAME, "CityId");
+        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST json_object_get_string(buf) );
+        xmlSetProp(node, BAD_CAST NAME, BAD_CAST "CityId");
         node = xmlAddChild(childNode, node);
         //json_object_put(buf);
 	
         buf = json_object_object_get(ht, CITY_KEY);
-        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, json_object_get_string(buf) );
-        xmlSetProp(node, NAME, "CityName");
+        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST json_object_get_string(buf) );
+        xmlSetProp(node, BAD_CAST NAME, BAD_CAST CITY_NAME);
         node = xmlAddChild(childNode, node);
         //json_object_put(buf);
 	
         //PARSE COUNTRY
         childNode = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_STRUCT, NULL );
-        xmlSetProp(childNode, NAME, "Country");
+        xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST "Country");
         childNode = xmlAddChild(rootNode, childNode);
 
         buf = json_object_object_get(ht, COUNTRY_ID_KEY);
-        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, json_object_get_string(buf) );
-        xmlSetProp(node, NAME, "CountryId");
+        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST json_object_get_string(buf) );
+        xmlSetProp(node, BAD_CAST NAME, BAD_CAST "CountryId");
         node = xmlAddChild(childNode, node);
         //json_object_put(buf);
 	
         buf = json_object_object_get(ht, COUNTRY_KEY);
-        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, json_object_get_string(buf) );
-        xmlSetProp(node, NAME, "CountryName");
-        node = xmlAddChild(childNode, node);	
+        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST json_object_get_string(buf) );
+        xmlSetProp(node, BAD_CAST NAME, BAD_CAST COUNTRY_NAME);
+        node = xmlAddChild(childNode, node);
         //json_object_put(buf);
         //json_object_put(ht);
         g_debug("free ht");
-	
+
         struct tm tm_date;
+        memset(&tm_date, 0, sizeof(struct tm));
 
         buf = json_object_object_get(profile, BIRTH_DAY_KEY );
+        g_debug("%s:%d: day=%s", __FILE__, __LINE__, json_object_get_string(buf));
         tm_date.tm_mday = json_object_get_int(buf);
         //json_object_put(buf);
-	
+
         buf = json_object_object_get(profile, BIRTH_MONTH_KEY);
+        g_debug("%s:%d: month=%s", __FILE__, __LINE__, json_object_get_string(buf));
         tm_date.tm_mon = json_object_get_int(buf) - 1;
         //json_object_put(buf);
 	
         buf = json_object_object_get(profile, BIRTH_YEAR_KEY);
+        g_debug("%s:%d: year=%s", __FILE__, __LINE__, json_object_get_string(buf));
         tm_date.tm_year = json_object_get_int(buf) - 1900;
         //json_object_put(buf);
 	
-        char* date = malloc(sizeof(char)*11);
-        strftime(date, 11, "%d.%m.%Y\0", &tm_date);
+        char date[20] = {0};
+        if (tm_date.tm_year > 0 && tm_date.tm_mon > -1 &&  tm_date.tm_mday > 0) {
+            //user set full date
+            strftime(date, 19, "%d.%m.%Y", &tm_date);
+        } else {
+               if (tm_date.tm_mon > -1 &&  tm_date.tm_mday > 0){
+                   //user set only day and month
+                   strftime(date, 19, "%d.%m", &tm_date);
+               } 
+               if (tm_date.tm_year > 0 && tm_date.tm_mon > -1){
+                   //user set only year and month
+                   strftime(date, 19, "%m.%Y", &tm_date);
+               }
+               if (tm_date.tm_year > 0 && tm_date.tm_mon == -1)
+               {
+                   //user set only year
+                   strftime(date, 19, "%Y", &tm_date);
+               }
+        }
+                
+        g_debug("date = %s", date);
 
-        node = xmlNewDocNode(doc, NULL, BAD_CAST "date", date);
-        xmlSetProp(node, NAME, "Birthday");
+        node = xmlNewDocNode(doc, NULL, BAD_CAST "date", BAD_CAST date);
+        xmlSetProp(node, BAD_CAST NAME, BAD_CAST BIRTHDAY_NAME);
         node = xmlAddChild(rootNode, node);
-        free(date);
 	
         //PARSE GENDER
         childNode = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_SELECT, NULL );
-        xmlSetProp(childNode, NAME, "Gender");
+        xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST GENDER_NAME);
         childNode = xmlAddChild(rootNode, childNode);
 
         buf = json_object_object_get(profile, MALE_KEY );
@@ -250,17 +271,17 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
         //json_object_put(buf);
 	
         for (i = 0; i < 3; i++) {
-            node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, gender[i]);
+            node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST gender[i]);
             if (sx_serialized == i)
-                xmlSetProp(node, "selected", "1");
+                xmlSetProp(node, BAD_CAST "selected", BAD_CAST "1");
             else
-                xmlSetProp(node, "selected", "0");
+                xmlSetProp(node, BAD_CAST "selected", BAD_CAST "0");
             node = xmlAddChild(childNode, node);	
         }
 
         //PARSE FAMILY STATE
         childNode = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_SELECT, NULL );
-        xmlSetProp(childNode, NAME, "FamilyState");
+        xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST FAMILY_STATE_NAME);
         childNode = xmlAddChild(rootNode, childNode);
 
 
@@ -269,17 +290,17 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
         //json_object_put(buf);
 	
         for (i = 0; i < 7; i++) {
-            node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, family_state[i]);
+            node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST family_state[i]);
             if (family_serialized == i)
-                xmlSetProp(node, "selected", "1");
+                xmlSetProp(node, BAD_CAST "selected", BAD_CAST "1");
             else
-                xmlSetProp(node, "selected", "0");
-            node = xmlAddChild(childNode, node);	
+                xmlSetProp(node, BAD_CAST "selected", BAD_CAST "0");
+            node = xmlAddChild(childNode, node);
         }
 
         //PARSE POLITICAL VIEW
         childNode = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_SELECT, NULL );
-        xmlSetProp(childNode, NAME, "PoliticalView");
+        xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST POLITICAL_VIEW_NAME);
         childNode = xmlAddChild(rootNode, childNode);
 
         buf = json_object_object_get(profile, POL_VIEW_KEY );
@@ -287,17 +308,17 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
         //json_object_put(buf);
 	
         for (i = 0; i < 9; i++) {
-            node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, pol_view[i]);
+            node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST pol_view[i]);
             if (pol_view_serialized == i)
-                xmlSetProp(node, "selected", "1");
+                xmlSetProp(node, BAD_CAST "selected", BAD_CAST "1");
             else
-                xmlSetProp(node, "selected", "0");
+                xmlSetProp(node, BAD_CAST "selected", BAD_CAST "0");
             node = xmlAddChild(childNode, node);	
         }
 
         //PARSE EDUCATION
         childNode = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_ARRAY, NULL );
-        xmlSetProp(childNode, NAME, "EducationList");
+        xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST "EducationList");
         childNode = xmlAddChild(rootNode, childNode);
 
         int length = 0;
@@ -314,29 +335,29 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
                 //json_object_put(buf);
                 if (buf_serialized < 21 || buf_serialized == 100 ) {
                     node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRUCT, NULL );
-                    xmlSetProp(node, NAME, "Education");
+                    xmlSetProp(node, BAD_CAST NAME, BAD_CAST "Education");
                     node = xmlAddChild(childNode, node);
                     if (buf_serialized < 21) {
-                        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, "School" );
+                        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST "School" );
                         node2 = xmlAddChild(node, node2);
                     } else { 
                         if (buf_serialized == 100) {
-                            node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, "High school");
+                            node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST "High school");
                             node2 = xmlAddChild(node, node2);
                         } 
                     }
-                    xmlSetProp(node2, NAME,"Type");
+                    xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "Type");
 
                     buf = json_object_array_get_idx(edu_item, 3 );		 
                     node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST json_object_get_string(buf));
                     node2 = xmlAddChild(node, node2);
-                    xmlSetProp(node2, NAME, "Name");
+                    xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "Name");
                     //json_object_put(buf);
 	
                     buf = json_object_array_get_idx(edu_item, 4 );
-                    node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, json_object_get_string(buf));
+                    node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST json_object_get_string(buf));
                     node2 = xmlAddChild(node, node2);
-                    xmlSetProp(node2, NAME, "DateComplete");
+                    xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "DateComplete");
                     //json_object_put(buf);
 	        }
 		//json_object_put(edu_item);
@@ -349,11 +370,10 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
         json_object_put(profile);
 	g_debug("free profile");
         return 0;
-    } else 
-        return 1;
-    
-    
- }
+    }
+
+    return 1;
+}
 
 /**
  * Parses json data, form xml friends list
@@ -367,13 +387,11 @@ int parser_friends(char *json, xmlDocPtr doc)
     int i=0;
     int length = 0;
     struct json_object *friend, *friends, *id, *name, *img, *status;
-    char* file_name;
     char** friend_name;
     char* friend_surname;
     char* tmp;
     xmlNodePtr rootNode, childNode, node,node2;
-    xmlAttrPtr attr;
-    
+
     rootNode = xmlDocGetRootElement(doc);     //response
     if(rootNode == NULL)
         return 0;   
@@ -383,11 +401,11 @@ int parser_friends(char *json, xmlDocPtr doc)
     childNode = rootNode->children;          //array
 
     if (childNode == NULL) {
-        node = xmlNewDocNode(doc, NULL, TYPE_ARRAY,  NULL);
+        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_ARRAY,  NULL);
         childNode = xmlAddChild(rootNode, node);
-        xmlSetProp(childNode, NAME, "contactList");
-        xmlSetProp(childNode, "from", "0");
-        xmlSetProp(childNode, "to", "0" );
+        xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST "contactList");
+        xmlSetProp(childNode, BAD_CAST "from", BAD_CAST "0");
+        xmlSetProp(childNode, BAD_CAST "to", BAD_CAST "0" );
     }
 
     friends = json_tokener_parse(json);
@@ -407,9 +425,9 @@ int parser_friends(char *json, xmlDocPtr doc)
             break;
         }
         node = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_STRUCT, NULL );
-        xmlSetProp(node, NAME, "contact");
+        xmlSetProp(node, BAD_CAST NAME, BAD_CAST "contact");
         tmp = g_strconcat(PREFIX, json_object_get_string(id), NULL);
-        xmlSetProp(node, "id", tmp);
+        xmlSetProp(node, BAD_CAST "id", BAD_CAST tmp);
         node = xmlAddChild(childNode, node);
         free(tmp);
 
@@ -423,16 +441,16 @@ int parser_friends(char *json, xmlDocPtr doc)
         friend_name = g_strsplit(json_object_get_string(name), " ",2);
         //json_object_put(name);
         if( friend_name[1] == NULL)
-            friend_surname = strdup(" ");
+            friend_surname = g_strdup(" ");
         else
-            friend_surname = strdup(friend_name[1]);
+            friend_surname = g_strdup(friend_name[1]);
 
-        tmp = g_strconcat(friend_surname," ",friend_name[0],NULL);
-        node2 = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_STRING, tmp);
+        tmp = g_strconcat(friend_surname, " ", friend_name[0], NULL);
+        node2 = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_STRING, BAD_CAST tmp);
         free(tmp); 
         free(friend_surname);
 
-        xmlSetProp(node2, NAME, "FriendName");
+        xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "FriendName");
         node2 = xmlAddChild(node, node2);
         g_strfreev (friend_name);
 
@@ -442,8 +460,8 @@ int parser_friends(char *json, xmlDocPtr doc)
             length = i;
             break;
         }	
-        node2 = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_STRING, json_object_get_string(status));
-        xmlSetProp(node2, NAME, "FriendStatus");
+        node2 = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_STRING, BAD_CAST json_object_get_string(status));
+        xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "FriendStatus");
         node2 = xmlAddChild(node, node2);
         //json_object_put(status);
 
@@ -457,21 +475,22 @@ int parser_friends(char *json, xmlDocPtr doc)
         g_debug("IMG=%s",json_object_get_string(img));
 
         node2 = xmlNewDocNode(doc, NULL,  BAD_CAST "img", NULL);
-        xmlSetProp(node2, NAME, "FriendImg");
-        if (strcmp(json_object_get_string(img),"0") != 0) {
-            xmlSetProp(node2, "uri", json_object_get_string(img));
+        xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "FriendImg");
+        if (strcmp(json_object_get_string(img), "0") != 0) {
+            xmlSetProp(node2, BAD_CAST "uri", BAD_CAST json_object_get_string(img));
         }
         node2 = xmlAddChild(node, node2);
         //json_object_put(img);
         //json_object_put(friend);
     }
     json_object_put(friends);
-    char* len_str;
-    len_str = xmlGetProp(childNode,"to");
-    tmp = g_strdup_printf("%d", length + atoi(len_str));
-    xmlSetProp(childNode, "to", tmp );
-    free(tmp);
-    free(len_str);
+    xmlChar* len_str = xmlGetProp(childNode, BAD_CAST "to");
+    tmp = g_strdup_printf("%d", length + atoi((gchar *)len_str));
+    xmlSetProp(childNode, BAD_CAST "to", BAD_CAST tmp);
+
+    g_free(tmp);
+    xmlFree(len_str);
+
     return length;
 }
 
@@ -484,47 +503,50 @@ int parser_friends(char *json, xmlDocPtr doc)
 int parser_messages(char *json, xmlDocPtr doc)
 {
     g_debug("parser_messages START");
+    //g_debug("Messages JSON: \n %s", json);
     int i = 0;
     int length = 0;
     struct json_object *mess, *message, *messages, *id, *sender, *time, *text, *status;
     char* tmp_str; 
-    xmlNodePtr rootNode, childNode, node,node2;
-    xmlAttrPtr attr;
+    xmlNodePtr rootNode = NULL, childNode = NULL, node = NULL, node2 = NULL;
 
     rootNode = xmlDocGetRootElement(doc);     //response 
     rootNode = rootNode->children;            //params
     childNode = rootNode->children;           //array
 
     if (childNode == NULL) {
-        node = xmlNewDocNode(doc, NULL, TYPE_ARRAY,  NULL);
+        node = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_ARRAY,  NULL);
         childNode = xmlAddChild(rootNode, node);
-        xmlSetProp(childNode, NAME, "messagetList");
-        xmlSetProp(childNode, "from", "0");
-        xmlSetProp(childNode, "to", "0" );
+        xmlSetProp(childNode, BAD_CAST NAME, BAD_CAST "messagetList");
+        xmlSetProp(childNode, BAD_CAST "from", BAD_CAST "0");
+        xmlSetProp(childNode, BAD_CAST "to", BAD_CAST "0" );
     }
 
     mess = json_tokener_parse(json);
     messages = json_object_object_get(mess,"d");
     length = json_object_array_length(messages);
     g_debug("Start parse");
-    length--;
+    if (length > PAGE_SIZE)
+        length = PAGE_SIZE;
     for(i = 0; i < length; i++) {
 
         message = json_object_array_get_idx(messages, i );
 
         if (message == NULL) {
-            xmlSetProp(childNode, "to", g_strdup_printf("%d", i + atoi(xmlGetProp(childNode,"to")) ) );
+    	    gchar *msg = g_strdup_printf("%d", i + atoi((gchar *)xmlGetProp(childNode, BAD_CAST "to")));
+            xmlSetProp(childNode, BAD_CAST "to",  BAD_CAST msg);
+            g_free(msg);
             return i;
         }
 
         id = json_object_array_get_idx(message, 0);
         node = xmlNewDocNode(doc, NULL,  BAD_CAST TYPE_STRUCT, NULL );
-        xmlSetProp(node, NAME, "message");
+        xmlSetProp(node, BAD_CAST NAME, BAD_CAST "message");
         if(id == NULL){
             break;
         }
         tmp_str = g_strconcat(PREFIX, json_object_get_string(id), NULL);
-        xmlSetProp(node, "id", tmp_str);
+        xmlSetProp(node, BAD_CAST "id", BAD_CAST tmp_str);
         node = xmlAddChild(childNode, node);
 	g_free(tmp_str);
 
@@ -536,8 +558,8 @@ int parser_messages(char *json, xmlDocPtr doc)
         if(id == NULL)
             break;
         tmp_str = g_strconcat(PREFIX, json_object_get_string(id), NULL);
-        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, tmp_str);
-        xmlSetProp(node2, NAME, "SenderId");
+        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST tmp_str);
+        xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "SenderId");
         node2 = xmlAddChild(node, node2);
         g_free(tmp_str);
 
@@ -548,12 +570,13 @@ int parser_messages(char *json, xmlDocPtr doc)
         if (json_object_get_string(id) != NULL) {
             name_list = g_strsplit(json_object_get_string(id), "\t", 2);
 	    tmp_str = g_strconcat(name_list[0], " ", name_list[1], NULL);
-            node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, tmp_str);
+            node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST tmp_str);
 	    g_free(tmp_str);
+            g_strfreev(name_list);
         } else {
                 node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, NULL);
         }
-        xmlSetProp(node2, NAME, "SenderName");
+        xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "SenderName");
         node2 = xmlAddChild(node, node2);
 
         sender = json_object_array_get_idx(message, 4);
@@ -563,8 +586,8 @@ int parser_messages(char *json, xmlDocPtr doc)
         if(id == NULL)
             break;
         tmp_str = g_strconcat(PREFIX, json_object_get_string(id), NULL);
-        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, tmp_str);
-        xmlSetProp(node2, NAME, "RecipientId");
+        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST tmp_str);
+        xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "RecipientId");
         node2 = xmlAddChild(node, node2);
         g_free(tmp_str);
 
@@ -574,14 +597,14 @@ int parser_messages(char *json, xmlDocPtr doc)
         if (json_object_get_string(id) != NULL) {
             name_list = g_strsplit(json_object_get_string(id), "\t", 2);
             tmp_str = g_strconcat(name_list[0], " ", name_list[1], NULL);
-            node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, tmp_str);
+            node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST tmp_str);
             g_free(tmp_str);
+            g_strfreev(name_list);
         } else {
                 node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, NULL);
         }
-        xmlSetProp(node2, NAME, "RecipientName");
+        xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "RecipientName");
         node2 = xmlAddChild(node, node2);
-        g_strfreev(name_list);
 
         //g_debug("parse_time");
         time = json_object_array_get_idx(message,1);
@@ -589,26 +612,26 @@ int parser_messages(char *json, xmlDocPtr doc)
             break;
         unsigned long int t;
         t = json_object_get_int(time);
-        
-        tmp_str = g_strdup_printf("%d",t);
-        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, tmp_str);
-        xmlSetProp(node2, NAME, "Time");
+
+        tmp_str = g_strdup_printf("%lu", t);
+        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST tmp_str);
+        xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "Time");
         node2 = xmlAddChild(node, node2);
         g_free(tmp_str);
 
         //g_debug("parse text");
-        text = json_object_array_get_idx(message,2);
+        text = json_object_array_get_idx(message, 2);
         if(text == NULL)
             break;
         char* mess_text;
         char* tmp;
         mess_text = json_object_get_string(text);
-        while((tmp = strstr(mess_text,"<br>"))!=NULL)
+        while((tmp = strstr(mess_text, "<br>")) != NULL)
         {
-            int k;
-            for(k=0;k<3;k++)
-                *(tmp+k)=' ';
-            *(tmp+k)='\n';
+            int k = 0;
+            for(; k < 3; k++)
+                *(tmp + k) = ' ';
+            *(tmp + k) = '\n';
         }
 
         char* temp;
@@ -618,31 +641,35 @@ int parser_messages(char *json, xmlDocPtr doc)
         temp = g_strdup(list[1]);
         g_strfreev (list);
 
-        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, temp);
-        xmlSetProp(node2, NAME, "Text");
+        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST temp);
+        xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "Text");
         node2 = xmlAddChild(node, node2);
         g_free(temp);
         
         //g_debug("parse read_status");
         status = json_object_array_get_idx(message,5);
-        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, json_object_get_string(status));
-        xmlSetProp(node2, NAME, "Status");
+        node2 = xmlNewDocNode(doc, NULL, BAD_CAST TYPE_STRING, BAD_CAST json_object_get_string(status));
+        xmlSetProp(node2, BAD_CAST NAME, BAD_CAST "Status");
         node2 = xmlAddChild(node, node2);
     }
     if(i != length){
-        xmlUnlinkNode(node);
-        xmlFreeNode(node);
+        if(node != NULL){
+            xmlUnlinkNode(node);
+            xmlFreeNode(node);
+        }
         length = i;
     }
     json_object_put(mess);
-    char* len_str;
-    len_str = xmlGetProp(childNode,"to");
-    tmp_str = g_strdup_printf("%d", length + atoi(len_str));
-    xmlSetProp(childNode, "to", tmp_str );
+    xmlChar* len_str = xmlGetProp(childNode, BAD_CAST "to");
+    tmp_str = g_strdup_printf("%d", length + atoi((gchar *)len_str));
+    xmlSetProp(childNode, BAD_CAST "to", BAD_CAST tmp_str );
+
     g_free(tmp_str);
-    g_free(len_str);
+    xmlFree(len_str);
+
+    g_debug("messages_length = %d", length);
     g_debug("parser_messages END");
-return length;
+    return length;
 }
 
 /**
@@ -669,5 +696,6 @@ int parser_new_messages(char* json)
             }
 	}
     }
+    return 0;
 }
    
